@@ -86,8 +86,8 @@ SimFunctions <- function(filename = NULL, dir = getwd(), comments = FALSE, singl
         LINE()
         if(comments) cat('\n### Run the simulation\n')
         cat('\nresults <- runSimulation(design=Design, replications=1000, ')
-        cat(sprintf('\n    generate=Generate, analyse=Analyse, %sedit=\'none\')',
-                    if(summarise) 'summarise=Summarise, ' else ''))
+        cat(sprintf('\n    generate=Generate, analyse=Analyse%s',
+                    if(summarise) ', summarise=Summarise)' else ')'))
         cat('\n\n')
     }
 
